FAWM.ORG | Slow day
Description: 14 songs in 28 days. What are you waiting for... inspiration?
Keywords: february national album writing month songwriting songs independent artists musicians music recording musical collaboration

- Summary
- Liner Notes
- Lyrics
- Comments

© 2020 FAWM.ORG

But lyrics and song content belong to the fawmers who wrote them! Donate · Credits · Help/FAQ · Terms · Privacy

## Slow day

by @elesimo

Feb 29 jam op-z instrumental electronic

Update Required To play the media you will need to either update your browser to a recent version or update your Flash plugin.
Auto-play songs Auto-advance to next song

#### Liner Notes

Another jam with my OP-Z and the Korg Mini Kaoss Pad 2S, for my last FAWM song of 2020.
I'm a great fan of the OP-Z and its workflow, and even though I've written a few dozens songs on it I'm still only knowledgeable of less than 50% of what it can do. The Kaoss Pad is a nice addition, I got it as a birthday gift in 2018 and I finally found a nice workflow for it, adding small effects to the OP-Z master track.

#### Lyrics

N/A

#### Comments

Leave a Comment. Log in to FAWM or sign up first...

- ##### @phylo Mar 3

  This tune is so sweet! The melody is very catchy. There are lots of little surprises in there. Nice work.

- ##### @kahlo2013 Mar 1

  This is really lovely feel-good kind of music that has a wonderful groove. The different instrumental layers - piano, bells, etc really play off each other quite well. Lovely composition and a pleasure to listen to!

- ##### @sadloaf Mar 1

  Fun song. The major tonality and the sort of post-chiptuney tones gave me a sort of I Am Robot And Proud feeling. Very jealous of anyone that owns an OP-Z lol.

- ##### @standup Mar 1

  Cool sounds, I like the flowing melody that drops in early. Great tones. Bell sounds and echoey bits! The echo might be the Kaoss ? but sounds like it's only on a certain part. I like the floating piano parts too. There's a lot here to like. Those delays throughout are adding a lot.
  I was briefly tempted by the OP-Z, but my synths are modular and softsynths, they do the job, and it would be another thing to learn!

#### Edit comment

- 2000 characters left. FAWM is a friendly place... keep it constructive!